@@ -8,9 +8,9 @@ use Exporter qw(import);
 use File::chdir;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-01-06'; # DATE
+our $DATE = '2024-12-21'; # DATE
 our $DIST = 'App-ThisDist'; # DIST
-our $VERSION = '0.023'; # VERSION
+our $VERSION = '0.024'; # VERSION
 
 our @EXPORT_OK = qw(this_dist this_mod);
 
@@ -196,13 +196,13 @@ sub this_dist {
         }
 
       FROM_ARCHIVE: {
-            require Filename::Perl::Release;
+            require Filename::Type::Perl::Release;
             # if there is a single archive in the directory which looks like a
             # perl release, use that.
             my @files = grep { -f } glob "*";
             my ($distfile, $dist, $ver);
             for my $file (@files) {
-                my $res = Filename::Perl::Release::check_perl_release_filename(filename=>$file);
+                my $res = Filename::Type::Perl::Release::check_perl_release_filename(filename=>$file);
                 next unless $res;
                 last FROM_ARCHIVE if defined $dist;
                 $dist = $res->{distribution};
@@ -259,7 +259,7 @@ App::ThisDist - Print Perl {distribution,module,author,...} associated with curr
 
 =head1 VERSION
 
-This document describes version 0.023 of App::ThisDist (from Perl distribution App-ThisDist), released on 2024-01-06.
+This document describes version 0.024 of App::ThisDist (from Perl distribution App-ThisDist), released on 2024-12-21.
 
 =head1 DESCRIPTION
 
@@ -338,7 +338,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2024, 2023, 2022, 2021, 2020 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
